@@ -3,7 +3,7 @@
  * c.h
  *    A few fundamental C definitions.
  *
- * Copyright (c) 2009-2012 Daniele Varrazzo <daniele.varrazzo@gmail.com>
+ * Copyright (c) 2009-2016 Daniele Varrazzo <daniele.varrazzo@gmail.com>
  *-------------------------------------------------------------------------
  */
 
@@ -32,6 +32,13 @@ typedef char bool;
 /* Let's use our version of strlcpy to avoid portability problems */
 size_t spt_strlcpy(char *dst, const char *src, size_t siz);
 
+/* VC defines _WIN32, not WIN32 */
+#ifdef _WIN32
+#ifndef WIN32
+#define WIN32 _WIN32
+#endif
+#endif
+
 #ifdef WIN32
 #include <Windows.h>
 #endif
